<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"  default-space="strip" result-encoding="ISO-8859-1"
	xmlns:nu="http://www.jclark.com/xt/java/com.sun.xmlsearch.tree.NodeUtils"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:office="http://openoffice.org/2000/office"
	xmlns:style="http://openoffice.org/2000/style"
	xmlns:text="http://openoffice.org/2000/text"
	xmlns:table="http://openoffice.org/2000/table"
	xmlns:draw="http://openoffice.org/2000/drawing"
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:xlink="http://www.w3.org/1999/xlink"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:meta="http://openoffice.org/2000/meta"
	xmlns:number="http://openoffice.org/2000/datastyle"
	xmlns:svg="http://www.w3.org/2000/svg"
	xmlns:chart="http://openoffice.org/2000/chart"
	xmlns:help="http://openoffice.org/2000/help">

	<!-- Possible values for Program are OFFICE, WRITER, CALC, DRAW, IMPRESS, CHART, MATH, IMAGE, PORTAL -->
<!--	<xsl:output method="xml"
				indent-result="yes"/> -->

	<xsl:param name="Language" select="'de'"/>
	<xsl:param name="Database" select="'swriter'"/>
	<xsl:param name="System" select="'WIN'"/>
	<xsl:variable name="Program">
		<xsl:choose>
			<xsl:when test="$Database='swriter'">WRITER</xsl:when>
			<xsl:when test="$Database='scalc'">CALC</xsl:when>
			<xsl:when test="$Database='sdraw'">DRAW</xsl:when>
			<xsl:when test="$Database='simpress'">IMPRESS</xsl:when>
			<xsl:when test="$Database='sbasic'">BASIC</xsl:when>
			<xsl:when test="$Database='smath'">MATH</xsl:when>
			<xsl:when test="$Database='schart'">CHART</xsl:when>
			<xsl:when test="$Database='portal'">PORTAL</xsl:when>
			<xsl:otherwise>NONE</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>		

	<xsl:template match="/">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="text:p[@text:style-name='Head 1']">
		<headingheading>
			<xsl:apply-templates/>
		</headingheading>
	</xsl:template>

	<xsl:template match="*|@*|comment()|processing-instruction()|text()">
	  <xsl:copy>
	    <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
	  </xsl:copy>
	</xsl:template>

	<xsl:template match="help:key-word">
		<xsl:element name="help:key-word">
			<xsl:attribute name="embedded">false</xsl:attribute>
			<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>


	<!-- Evaluating program switch document  -->

	<xsl:template match="help:switch">
		<xsl:if test="@select='Program'">
			<xsl:apply-templates mode="switch_prog"/>
		</xsl:if>
		<xsl:if test="@select='System'">
			<xsl:apply-templates mode="switch_sys"/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="help:case" mode="switch_prog">
		<xsl:if test="@select=$Program">
			<xsl:apply-templates/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="help:case" mode="switch_sys">
		<xsl:if test="@select=$System">
			<xsl:apply-templates/>
		</xsl:if>
	</xsl:template>


	<xsl:template match="help:default" mode="switch_prog">
		<xsl:if test="not(../help:case[@select=$Program])">
			<xsl:apply-templates/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="help:default" mode="switch_sys">
		<xsl:if test="not(../help:case[@select=$System])">
			<xsl:apply-templates/>
		</xsl:if>
	</xsl:template>


	<!-- Special mode for embedding documents  -->

	<xsl:template match="help:embedded">
		<xsl:variable name="Link" select="concat('vnd.sun.star.help://',$Database,'/',@Id,'?Language=',$Language)"/>
		<xsl:variable name="EmbeddedDoc" select="document($Link)"/>
		<xsl:variable name="Docpart" select="@Eid"/>
		<xsl:apply-templates select="$EmbeddedDoc//help:to-be-embedded[@Eid=$Docpart]" mode="embedded"/>
	</xsl:template>

	<xsl:template match="*|@*|comment()|processing-instruction()|text()" mode="embedded">
	  <xsl:copy>
		 <xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()" mode="embedded"/>
	  </xsl:copy>
	</xsl:template>

	<xsl:template match="help:key-word" mode="embedded">
		<xsl:element name="help:key-word">
			<xsl:attribute name="embedded">true</xsl:attribute>
			<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()" mode="embedded"/>
		</xsl:element>
	</xsl:template>

</xsl:stylesheet>