<xsl:stylesheet  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				 xmlns:xt="http://www.jclark.com/xt"
				 xmlns:office="http://openoffice.org/2000/office"
				 xmlns:style="http://openoffice.org/2000/style"
				 xmlns:text="http://openoffice.org/2000/text"
				 xmlns:table="http://openoffice.org/2000/table"
				 xmlns:draw="http://openoffice.org/2000/drawing"
				 xmlns:fo="http://www.w3.org/1999/XSL/Format"
				 xmlns:xlink="http://www.w3.org/1999/xlink"
				 xmlns:dc="http://purl.org/dc/elements/1.1/"
				 xmlns:meta="http://openoffice.org/2000/meta"
				 xmlns:number="http://openoffice.org/2000/datastyle"
				 xmlns:svg="http://www.w3.org/2000/svg"
				 xmlns:chart="http://openoffice.org/2000/chart"
				 xmlns:help="http://openoffice.org/2000/help">



	<!-- ************ -->
	<!-- *** body *** -->
	<!-- ************ -->

        <xsl:template match="office:document/office:body">


	<!-- only DEBUG purpose: shows the inlined style attributes of the temporary variable >
	<xsl:if test="$DEBUG and not($deviceType = 'CSS')">
		<xsl:element name="debug_tree_of_styles"><xsl:text>
			</xsl:text><xsl:for-each select="$style-attribute-tree/allstyles/*">
<xsl:text>                      </xsl:text><xsl:value-of select="name()"/><xsl:text> = </xsl:text><xsl:value-of select="."/><xsl:text>
			</xsl:text>
					</xsl:for-each>
		</xsl:element>
	</xsl:if>
-->

		<xsl:apply-templates/>
	</xsl:template>


	<!-- deactivating default template -->
	<xsl:template match="*"/>




	<!-- ################### -->
	<!-- ### INLINE-TEXT ### -->
	<!-- ################### -->


	<!-- ****************** -->
	<!-- *** Paragraphs *** -->
	<!-- ****************** -->

	<xsl:template match="text:p | draw:text-box | draw:page">
			<xsl:variable name="deviceType">
				<xsl:choose>
					<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
					<xsl:otherwise>CSS</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>

			<xsl:choose>
				<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
				<xsl:when test="$deviceType = 'CSS'">
					<xsl:element name="p">
						<xsl:attribute name="class"><xsl:value-of select="translate(@text:style-name, '. ', '')"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>

				<!--+++++ HTML 4.0 INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'HTML4'">
					<xsl:element name="p">
						<xsl:attribute name="style"><xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>
				<!--+++++ PALM 3.2 SUBSET INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'PALM'">
					<xsl:choose>
						<xsl:when test="name(parent::*) = 'text:list-item'">
							<!-- !!! xsl:apply-templates will be called implicit !!! -->
							<xsl:call-template name="create-nested-format-tags">
								<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
								<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="p">
								<!-- !!! xsl:apply-templates will be called implicit !!! -->
								<xsl:call-template name="create-nested-format-tags">
									<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
									<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
								</xsl:call-template>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!--+++++ WML / WAP  +++++-->
				<xsl:otherwise>
					<!-- no nested p tags in wml1.1 allowed -->
					<xsl:choose>
						<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
							<!-- !!! xsl:apply-templates will be called implicit !!! -->
							<xsl:call-template name="create-nested-format-tags">
								<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
								<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="p">
								<!-- !!! xsl:apply-templates will be called implicit !!! -->
								<xsl:call-template name="create-nested-format-tags">
									<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
									<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
								</xsl:call-template>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
	</xsl:template>


	<!-- **************** -->
	<!-- *** Headings *** -->
	<!-- **************** -->

	<xsl:template match="text:h">

		<xsl:variable name="deviceType">
			<xsl:choose>
				<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
				<xsl:otherwise>CSS</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="headertyp" select="concat('h', @text:level)"/>

		<xsl:element name="{$headertyp}">
			<xsl:choose>
				<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
				<xsl:when test="$deviceType = 'CSS'">
					<xsl:attribute name="class"><xsl:value-of select="translate(@text:style-name, '. ', '')"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>

				<!--+++++ HTML 4.0 INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'HTML4'">
					<xsl:attribute name="style"><xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:when>

				<!--+++++ PALM 3.2 SUBSET INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'PALM'">
					<!-- !!! xsl:apply-templates will be called implicit !!! -->
					<xsl:call-template name="create-attribute-ALIGN">
						<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
						<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
					</xsl:call-template>
				</xsl:when>

				<!--+++++ WML / WAP  +++++-->
				<xsl:otherwise>
					<!-- no nested p tags in wml1.1 allowed -->
					<xsl:choose>
						<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
							<!-- since no header styles exist, an emphasis is used -->
							<xsl:element name="em">
								<xsl:apply-templates/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="p">
								<!-- since no header styles exist, an emphasis is used -->
								<xsl:element name="em">
									<xsl:apply-templates/>
								</xsl:element>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>



	<!-- ***************** -->
	<!-- *** Text Span *** -->
	<!-- ***************** -->

	<xsl:template match="text:span">
			<xsl:variable name="deviceType">
				<xsl:choose>
					<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
					<xsl:otherwise>CSS</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
	
			<xsl:choose>
				<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
				<xsl:when test="$deviceType = 'CSS'">
					<xsl:element name="span">
						<xsl:attribute name="class"><xsl:value-of select="translate(@text:style-name, '. ', '')"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>

				<!--+++++ HTML 4.0 INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'HTML4'">
					<xsl:element name="span">
						<xsl:attribute name="style"><xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>
				<!--+++++ PALM 3.2 SUBSET INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'PALM'">
					<xsl:choose>
						<xsl:when test="name(parent::*) = 'text:list-item'">
							<!-- !!! xsl:apply-templates will be called implicit !!! -->
							<xsl:call-template name="create-nested-format-tags">
								<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
								<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="p">
								<!-- !!! xsl:apply-templates will be called implicit !!! -->
								<xsl:call-template name="create-nested-format-tags">
									<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
									<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
								</xsl:call-template>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!--+++++ WML / WAP  +++++-->
				<xsl:otherwise>
					<!-- no nested p tags in wml1.1 allowed -->
					<xsl:choose>
						<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
							<!-- !!! xsl:apply-templates will be called implicit !!! -->
							<xsl:call-template name="create-nested-format-tags">
								<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
								<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="p">
								<!-- !!! xsl:apply-templates will be called implicit !!! -->
								<xsl:call-template name="create-nested-format-tags">
									<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
									<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
								</xsl:call-template>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>

			</xsl:choose>
	</xsl:template>


	<!-- ************* -->
	<!-- *** Link  *** -->
	<!-- ************* -->

	<xsl:template match="text:a | draw:a | office:a">
	
	
		<xsl:variable name="deviceType">
			<xsl:choose>
				<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
				<xsl:otherwise>CSS</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<!-- workaround of an writer buck (empty hrefs) fixed in SRC617 -->
		<xsl:choose>
			<xsl:when test="not(@xlink:href='')">		
				<xsl:choose>
					<xsl:when test="not($deviceType = 'WML')">
						<xsl:element name="a">
							<xsl:attribute name="href"><xsl:value-of select="@xlink:href"/></xsl:attribute>
							<xsl:attribute name="class">ContentLink</xsl:attribute>
							<xsl:apply-templates/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<!-- no nested p tags in wml1.1 allowed -->
						<xsl:choose>
							<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
								<xsl:element name="a">
									<xsl:attribute name="href"><xsl:value-of select="@xlink:href"/></xsl:attribute>
									<xsl:apply-templates select="descendant::text()"/>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:element name="p">
									<xsl:element name="a">
										<xsl:attribute name="href"><xsl:value-of select="@xlink:href"/></xsl:attribute>
										<xsl:apply-templates select="descendant::text()"/>
									</xsl:element>
								</xsl:element>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>			
	</xsl:template>

<!--DOCU_HELP_SPECIAL:START-->

	<!-- ******************* -->
	<!-- *** Image Link  *** -->
	<!-- ******************* -->

	<xsl:template match="draw:image | office:image">
		<xsl:element name="{name()}">
			<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
		</xsl:element>
	</xsl:template>

    <xsl:template match="draw:image/@* | office:image/@*">
		<xsl:copy>
			<xsl:apply-templates select="*|@*|comment()|processing-instruction()|text()"/>
		</xsl:copy>
	</xsl:template>
<!--DOCU_HELP_SPECIAL:END-->							


	<!-- ******************** -->
	<!-- *** ordered list *** -->
	<!-- ******************** -->

	<xsl:template match="text:ordered-list">
		<xsl:variable name="deviceType">
			<xsl:choose>
				<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
				<xsl:otherwise>CSS</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

	
			<xsl:choose>
				<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
				<xsl:when test="$deviceType = 'CSS'">
					<xsl:element name="ol">
						<xsl:attribute name="class"><xsl:value-of select="translate(@text:style-name, '. ', '')"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>
				<!--+++++ HTML 4.0 INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'HTML4'">
					<xsl:element name="ol">
						<xsl:attribute name="style"><xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>
				<!--+++++ PALM 3.2 SUBSET AND WAP INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'PALM'">
					<xsl:element name="ol">
<!--                    <xsl:call-template name="create-list-attributes">
							<!~~ the style-output-nodset is already prepared by the included section style_mapping.xsl ~~>
							<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
						</xsl:call-template>-->
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>
				<!--+++++ WML / WAP  +++++-->
				<xsl:otherwise>
					<xsl:choose>
						<!-- simulating content break of capsulated list elements -->
						<xsl:when test="ancestor::text:list-item">
							<xsl:choose>
								<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
									<!-- simulating content break of capsulated list elements -->
									<xsl:element name="br"></xsl:element>
									<xsl:apply-templates/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:element name="p">
										<!-- simulating content break of capsulated list elements -->
										<xsl:element name="br"></xsl:element>
										<xsl:apply-templates/>
									</xsl:element>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
	</xsl:template>



	<!-- ********************** -->
	<!-- *** unordered list *** -->
	<!-- ********************** -->

	<xsl:template match="text:unordered-list">
		<xsl:variable name="deviceType">
			<xsl:choose>
				<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
				<xsl:otherwise>CSS</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	
		<xsl:choose>
			<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
			<xsl:when test="$deviceType = 'CSS'">
				<xsl:element name="ul">
					<xsl:attribute name="class"><xsl:value-of select="translate(@text:style-name, '. ', '')"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>

			<!--+++++ HTML 4.0 INLINED WAY  +++++-->
			<xsl:when test="$deviceType = 'HTML4'">
				<xsl:element name="ul">
					<xsl:attribute name="style"><xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>

			<!--+++++ PALM 3.2 SUBSET AND WAP INLINED WAY  +++++-->
			<xsl:when test="$deviceType = 'PALM'">
				<xsl:element name="ul">
<!--                    <xsl:call-template name="create-list-attributes">
							<!~~ the style-output-nodset is already prepared by the included section style_mapping.xsl ~~>
							<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
						</xsl:call-template>-->
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>

			<!--+++++ WML / WAP  +++++-->
			<xsl:otherwise>
				<xsl:choose>
					<!-- simulating content break of capsulated list elements -->
					<xsl:when test="ancestor::text:list-item">
						<xsl:choose>
							<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
								<!-- simulating content break of capsulated list elements -->
								<xsl:element name="br"></xsl:element>
								<xsl:apply-templates/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:element name="p">
									<!-- simulating content break of capsulated list elements -->
									<xsl:element name="br"></xsl:element>
									<xsl:apply-templates/>
								</xsl:element>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates/>
					</xsl:otherwise>
				</xsl:choose>
<!--
				<xsl:choose>
					<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
						<!~~ simulating content break of capsulated list elements ~~>
						<xsl:if test="ancestor::text:list-item">
							<!~~ ASCII table row end simulation ~~>
							<xsl:element name="br"></xsl:element>
						</xsl:if>
						<xsl:apply-templates/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="p">
							<!~~ simulating content break of capsulated list elements ~~>
							<xsl:if test="ancestor::text:list-item">
								<!~~ ASCII table row end simulation ~~>
								<xsl:element name="br"></xsl:element>
							</xsl:if>
							<xsl:apply-templates/>
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
-->
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>



	<!-- ****************** -->
	<!-- *** list item  *** -->
	<!-- ****************** -->

	<xsl:template match="text:list-item|text:list-header">
		<xsl:variable name="deviceType">
			<xsl:choose>
				<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
				<xsl:otherwise>CSS</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	
		<xsl:choose>
			<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
			<xsl:when test="$deviceType = 'CSS'">
				<xsl:element name="li">
					<xsl:attribute name="class"><xsl:value-of select="translate(@text:style-name, '. ', '')"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>

			<!--+++++ HTML 4.0 INLINED WAY  +++++-->
			<xsl:when test="$deviceType = 'HTML4'">
				<xsl:element name="li">
					<xsl:attribute name="style"><xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>

			<!--+++++ PALM 3.2 SUBSET AND WAP INLINED WAY  +++++-->
			<xsl:when test="$deviceType = 'PALM'">
				<xsl:element name="li">
<!--                    <xsl:call-template name="create-list-attributes">
							<!~~ the style-output-nodset is already prepared by the included section style_mapping.xsl ~~>
							<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
						</xsl:call-template>-->
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>

			<!--+++++ WML / WAP  +++++-->
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
						<!-- simulating list elements -->
						<xsl:for-each select="ancestor::text:list-item">*</xsl:for-each>
						<xsl:text>* </xsl:text>
						<xsl:apply-templates/>
						<!-- list item break simulation (not in a table)-->
						<xsl:if test="not(ancestor::table:table-cell) or following-sibling::text:list-item">
							<xsl:element name="br"/>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="p">
							<!-- simulating list elements -->
							<xsl:for-each select="ancestor::text:list-item">*</xsl:for-each>
							<xsl:text>* </xsl:text>
							<xsl:apply-templates/>
							<!-- list item break simulation (not in a table)-->
							<xsl:if test="not(ancestor::table:table-cell) or following-sibling::text:list-item">
								<xsl:element name="br"/>
							</xsl:if>
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>



	<!-- ********************************************** -->
	<!-- *** Text Section (contains: draw:text-box) *** -->
	<!-- ********************************************** -->

	<xsl:template match="text:section">
		<xsl:variable name="deviceType">
			<xsl:choose>
				<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
				<xsl:otherwise>CSS</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>	

		<xsl:if test="contains(@text:display, 'true')">
			<xsl:choose>
				<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
				<xsl:when test="$deviceType = 'CSS'">
					<xsl:element name="span">
						<xsl:attribute name="class"><xsl:value-of select="translate(@text:style-name, '. ', '')"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>
				<!--+++++ HTML 4.0 INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'HTML4'">
					<xsl:element name="span">
						<xsl:attribute name="style"><xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/></xsl:attribute>
						<xsl:apply-templates/>
					</xsl:element>
				</xsl:when>
				<!--+++++ PALM 3.2 SUBSET INLINED WAY  +++++-->
				<xsl:when test="$deviceType = 'PALM'">
					<xsl:choose>
						<xsl:when test="name(parent::*) = 'text:list-item'">
							<!-- !!! xsl:apply-templates will be called implicit !!! -->
							<xsl:call-template name="create-nested-format-tags">
								<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
								<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="p">
								<!-- !!! xsl:apply-templates will be called implicit !!! -->
								<xsl:call-template name="create-nested-format-tags">
									<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
									<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
								</xsl:call-template>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!--+++++ WML / WAP  +++++-->
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="not($deviceType = 'WML')">
							<xsl:element name="a">
								<xsl:attribute name="href"><xsl:value-of select="@xlink:href"/></xsl:attribute>
								<xsl:apply-templates/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<!-- no nested p tags in wml1.1 allowed -->
							<xsl:choose>
								<xsl:when test="ancestor::*[contains($wap-paragraph-elements, name())]">
									<!-- !!! xsl:apply-templates will be called implicit !!! -->
									<xsl:call-template name="create-nested-format-tags">
										<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
										<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:element name="p">
										<!-- !!! xsl:apply-templates will be called implicit !!! -->
										<xsl:call-template name="create-nested-format-tags">
											<!-- the style-output-nodset is already prepared by the included section style_mapping.xsl -->
											<xsl:with-param name="format-nodeset" select="$style-attribute-tree/allstyles/*[name()=current()/@text:style-name]"/>
										</xsl:call-template>
									</xsl:element>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
<!--
	<xsl:template match="draw:text-box">
		<xsl:apply-templates/>
	</xsl:template>
-->

</xsl:stylesheet>