<xsl:stylesheet  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				 xmlns:xt="http://www.jclark.com/xt"
				 xmlns:office="http://openoffice.org/2000/office"
				 xmlns:style="http://openoffice.org/2000/style"
				 xmlns:text="http://openoffice.org/2000/text"
				 xmlns:table="http://openoffice.org/2000/table"
				 xmlns:draw="http://openoffice.org/2000/drawing"
				 xmlns:fo="http://www.w3.org/1999/XSL/Format"
				 xmlns:xlink="http://www.w3.org/1999/xlink"
				 xmlns:dc="http://purl.org/dc/elements/1.1/"
				 xmlns:meta="http://openoffice.org/2000/meta"
				 xmlns:number="http://openoffice.org/2000/datastyle"
				 xmlns:svg="http://www.w3.org/2000/svg"
				 xmlns:chart="http://openoffice.org/2000/chart"
				 xmlns:help="http://openoffice.org/2000/help">
				<!--DOCU_HELP_SPECIAL:START-->
					  <!-- the HELP namespace-->

				 <!--DOCU_HELP_SPECIAL:END-->

	<xsl:output method="xml"
				indent-result="yes"/>
		   <!-- doctype-system="./entities.dtd"	-->


	<!--+++++ INCLUDED XSL MODULES +++++-->


	  <!-- inherited style properties will be collected and written in a CSS header (CSS) -->
	<xsl:include href="style_header.xsl"/>
	  <!-- inherited style properties will be collected and written as html properties in a temporary variable (HTML4, PALM) -->
	<xsl:include href="style_inlined.xsl"/>
	  <!-- our xml style properties will be mapped to CSS and HTML4.x properties -->
	<xsl:include href="style_mapping.xsl"/>
	  <!-- common element handling -->
	<xsl:include href="common.xsl"/>
	  <!-- table handling -->
	<xsl:include href="table.xsl"/>
<!--DOCU_HELP_SPECIAL:START-->

	  <!-- documentation handling -->
	<xsl:include href="help.xsl"/>
<!--DOCU_HELP_SPECIAL:END-->


	<!--+++++ PARAMETER FROM THE APPLICATION AND GLOBAL VARIABLES +++++-->
	<!--    all possible deviceTyps:
		<xsl:param name="deviceType" select="'CSS'"/>
		<xsl:param name="deviceType" select="'HTML4'"/>
		<xsl:param name="deviceType" select="'PALM'"/>
	-->
	<!--    style-sections stored as variable as extern section could be possible later -->
	<xsl:variable name="automatic-styles-node" select="/office:document/office:automatic-styles"/>
	<xsl:variable name="templates-styles-node" select="/office:document/office:styles"/>

	<!--    for activating the debug mode set the variable to 'true()' -->
	<xsl:variable name="DEBUG"   select="false"/>


<!--DOCU_HELP_SPECIAL:START-->
	<!--    to access the variable like a node-set it is necessary to convert it
			from a result-tree-fragment (RTF) to a node set using the James Clark extension-->
	<xsl:variable name="style-attribute-tree-RTF">
		<xsl:call-template name='create-all-inline-styles'/>
	</xsl:variable>
	<xsl:variable name="style-attribute-tree" select="xt:node-set($style-attribute-tree-RTF)"/>
<!--DOCU_HELP_SPECIAL:END-->


<!--DOCU_HELP_SPECIAL:START~~
	<!~~    user-agent will be differntiated by this parameter given by application (e.g. java servlet)~~>
	<xsl:variable name="deviceType">
		<xsl:choose>
			<xsl:when test="ancestor::help:to-be-embedded and $automatic-styles-node/style:style[@style:name=current()/@text:style-name]">HTML4</xsl:when>
			<xsl:otherwise>CSS</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
<!~~DOCU_HELP_SPECIAL:END-->


	<!-- ************************************* -->
	<!-- *** build the propriate HTML file *** -->
	<!-- ************************************* -->

	<xsl:template match="/">
<!--
		<xsl:call-template name="buildHtmlFile"/>
	</xsl:template>

	<xsl:template name="buildHtmlFile">
-->
		<xsl:choose>
			<!--+++++ CSS (CASCADING STLYE SHEET) HEADER STYLE WAY +++++-->
			<xsl:when test="true()">
				<xsl:element name="html">
					<xsl:element name="head">
						<xsl:call-template name='common-header-properties'/>

						<!-- constructing the css header simulating inheritance of style-families by style order -->
						<xsl:call-template name='create-header-styles'/>
					</xsl:element>

					<xsl:element name="body">
						<!-- processing the content of the xml file -->
						<xsl:apply-templates select="office:document/office:body"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>



			<!--+++++ HTML 4.0 INLINED WAY  +++++
			<xsl:when test="$deviceType = 'HTML4'">
				<xsl:element name="html">
					<xsl:element name="head">
						<xsl:call-template name='common-header-properties'/>
					</xsl:element>

					<xsl:element name="body">
						<xsl:apply-templates select="office:document/office:body"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>

			<!~~+++++ PALM-VII (3.2 HTML SUBSET)  +++++~~>
			<xsl:when test="$deviceType = 'PALM'">
				<!~~ the proxy will convert the html file later to PQA ~~>
				<xsl:element name="html">
					<xsl:element name="head">
						<xsl:call-template name='palm-header-properties'/>
					</xsl:element>

					<xsl:element name="body">
						<!~~ processing the content of the xml file ~~>
						<xsl:apply-templates select="office:document/office:body"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
			-->
		</xsl:choose>
	</xsl:template>



	<!-- **************************** -->
	<!-- *** HTML4 and CSS header *** -->
	<!-- **************************** -->

	<xsl:template name='common-header-properties'>
<!--DOCU_HELP_SPECIAL:START-->
			<xsl:apply-templates select="/office:document/office:meta/dc:subject"/>
			<xsl:apply-templates select="/office:document/office:meta/dc:description"/>
                        <xsl:apply-templates select="/office:document/office:meta/dc:language"/>
			<!--
			<xsl:element name="link">
				<xsl:attribute name="rel">stylesheet</xsl:attribute>
				<xsl:attribute name="type">text/css</xsl:attribute>
				<xsl:attribute name="href">style.css</xsl:attribute>
			 </xsl:element>
			 -->
			 <xsl:element name="help:css-file-link"/>
<!--DOCU_HELP_SPECIAL:END-->
	</xsl:template>

</xsl:stylesheet>
