<xsl:stylesheet  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				 xmlns:xt="http://www.jclark.com/xt"
				 xmlns:office="http://openoffice.org/2000/office"
				 xmlns:style="http://openoffice.org/2000/style"
				 xmlns:text="http://openoffice.org/2000/text"
				 xmlns:table="http://openoffice.org/2000/table"
				 xmlns:draw="http://openoffice.org/2000/drawing"
				 xmlns:fo="http://www.w3.org/1999/XSL/Format"
				 xmlns:xlink="http://www.w3.org/1999/xlink"
				 xmlns:dc="http://purl.org/dc/elements/1.1/"
				 xmlns:meta="http://openoffice.org/2000/meta"
				 xmlns:number="http://openoffice.org/2000/datastyle"
				 xmlns:svg="http://www.w3.org/2000/svg"
				 xmlns:chart="http://openoffice.org/2000/chart"
				 xmlns:help="http://openoffice.org/2000/help">



	<!-- ****************************** -->
	<!-- *** style sheet processing *** -->
	<!-- ****************************** -->


	<xsl:template name='create-header-styles'>
		<xsl:comment>
			<xsl:text>The CSS style header method for setting styles</xsl:text>
		</xsl:comment>
		<xsl:element name="style">
			<xsl:attribute name="type">text/css</xsl:attribute>
			<xsl:text>

		</xsl:text>
<!--DOCU_HELP_SPECIAL:START-->
<!-- NO HEADER STYLES FOR DOCU WANTED -	THEY ARE WRITTEN IN AN EXTERN FILE -->
				<!-- styles in the office:styles section (here: value of templates-styles-node) are parent
					 styles from styles of the office:styles or office:automatic-styles.
					 As possible parent of all, they are first created, beginning with the top-level parents,
					 the styles without a parent.
					 In the folling template all their children will be recursivly traversed -->
<!--
				<xsl:for-each select="$templates-styles-node/style:style[not(@style:parent-style-name)]">
					<xsl:call-template name="write-header-properties"/>
				</xsl:for-each>				

				<xsl:text> </xsl:text>
-->
<!--DOCU_HELP_SPECIAL:END-->				

				<!-- a style in the office:automatic-styles section (here: value of automatic-styles-node) can
					 only be parent of a style in the office:automatic-styles section.
					 Also beginning with top-level style first,  all children style will be recursivly traversed -->
			<xsl:for-each select="$automatic-styles-node/style:style">
				<xsl:call-template name="write-header-properties">
					<xsl:with-param name="searchOnlyInAutomaticStyles" select="true()"/>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:element>

	</xsl:template>




	<xsl:template name='write-header-properties'>
		<xsl:param name="searchOnlyInAutomaticStyles"/>

		<!-- write out the name of the current (parent) style in the CSS headersection (e.g. "span.myStyle") -->
		<xsl:call-template name="write-css-style-name">
			<xsl:with-param name="beginning-element" select="true()"/>
		</xsl:call-template>

		<!-- the names of all styles children will be written out(office:style AND office:automatic-style) 
		<xsl:call-template name="write-child-names">
			<xsl:with-param name="parentStyleName"          select="@style:name"/>
			<xsl:with-param name="parentStyleFamily"        select="@style:family"/>
			<xsl:with-param name="searchOnlyInAutomaticStyles"/>
		</xsl:call-template>
docu-->

		<!-- the style propterties of the first style (parent) is written out -->
		<xsl:text>{
				</xsl:text>
				<!--new for docu -->
				<xsl:value-of select="$style-attribute-tree/allstyles/*[name()=current()/@style:name]"/>
<!--docu				
			<xsl:call-template name="transformStyleElements">
				<xsl:with-param name="styleAttributePath"   select="current()/style:properties/@*"/>
			</xsl:call-template>
-->			
		<xsl:text>}
		</xsl:text>

		<!-- RECURSION WITH ENDCONDITON: adding style classes for all existing childs -->
		<xsl:variable name="parentStyleName"    select="@style:name"/>
		<xsl:variable name="parentStyleFamily"  select="@style:family"/>

		<xsl:if test="not(searchOnlyInAutomaticStyles)">
			<xsl:for-each select="../style:style[@style:family=$parentStyleFamily and @style:parent-style-name=$parentStyleName]">
				<xsl:call-template name="write-header-properties"/>
			</xsl:for-each>
		</xsl:if>
		<xsl:for-each select="$automatic-styles-node/style:style[@style:family=$parentStyleFamily and @style:parent-style-name=$parentStyleName]">
			<xsl:call-template name="write-header-properties">
				<xsl:with-param name="searchOnlyInAutomaticStyles"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>

	<!--++
		  The parent style will be written out!
		  For each Style:family a prefix must be added
			<!ENTITY % styleFamily 
			"(paragraph|text|section|table|table-column|table-row|table-cell|table-page|chart|graphics|default|drawing-page|presentation|control)">			
		++-->
	<xsl:template name="write-css-style-name">
		<xsl:param name="beginning-element"/>

		<xsl:if test="not($beginning-element)">
			<xsl:text>, </xsl:text>
		</xsl:if>

		<xsl:choose>
			<xsl:when test="@style:family='paragraph'">
				<xsl:value-of select="concat('p.', translate(@style:name, '. ', ''))"/>
			</xsl:when>
			<xsl:when test="@style:family='text'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>
			<xsl:when test="@style:family='section'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>			
			<xsl:when test="@style:family='table'">
				<xsl:value-of select="concat('table.', translate(@style:name, '. ', ''))"/>
			</xsl:when>
			<xsl:when test="@style:family='table-column'">
			<!-- as column styles have to be included as span styles AFTER the table (no two class attributes in TD allowed!
				<xsl:value-of select="concat('td.', translate(@style:name, '. ', ''))"/><xsl:text>, </xsl:text>-->
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>
			<xsl:when test="@style:family='table-row'">
				<xsl:value-of select="concat('tr.', translate(@style:name, '. ', ''))"/>
			</xsl:when>
			<xsl:when test="@style:family='table-cell'">
				<xsl:value-of select="concat('td.', translate(@style:name, '. ', ''))"/>
			</xsl:when>
			<xsl:when test="@style:family='table-page'">
				<xsl:value-of select="concat('.', translate(@style:name, '. ', ''))"/>
			</xsl:when>
			<xsl:when test="@style:family='chart'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>			
			<xsl:when test="@style:family='graphics'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>			
			<xsl:when test="@style:family='default'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>			
			<xsl:when test="@style:family='drawing-page'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>			
			<xsl:when test="@style:family='presentation'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>			
			<xsl:when test="@style:family='control'">
				<xsl:value-of select="concat('span.', translate(@style:name, '. ', ''))"/>
			</xsl:when>																					
		</xsl:choose>
	</xsl:template>


	<!-- finding all style child of a section and give their styleIdentifier to the output -->
	<xsl:template name='write-child-names'>
		<xsl:param name="parentStyleName" select="@style:name"/>
		<xsl:param name="parentStyleFamily" select="@style:family"/>
		<xsl:param name="searchOnlyInAutomaticStyles"/>


		<!--** the names of all office:styles children will be written out
			** (a automatic style can only have children in the office:automatic-style section) -->

		<!-- if NOT called from a office:automatic-style parent -->
		<xsl:if test="not(searchOnlyInAutomaticStyles)">
			<!-- for all children in the office:style section -->
			<xsl:for-each select="../style:style[@style:family=$parentStyleFamily and @style:parent-style-name=$parentStyleName]">
				<!-- write the style name in the css header -->
				<xsl:call-template name="write-css-style-name"/>

				<!-- search for child styles -->
				<xsl:call-template name="write-child-names">
					<xsl:with-param name="parentStyleName" select="@style:name"/>
					<xsl:with-param name="parentStyleFamily" select="@style:family"/>
				</xsl:call-template>

			</xsl:for-each>
		</xsl:if>

		<!--** the names of all office:automatic-styles children will be written out -->

		<!-- for all children in the office:automatic-style section -->
		<xsl:for-each select="$automatic-styles-node/style:style[@style:family=$parentStyleFamily and @style:parent-style-name=$parentStyleName]">
			<!-- write the style name in the css header -->
			<xsl:call-template name="write-css-style-name"/>

			<!-- search for child styles -->
			<xsl:call-template name="write-child-names">
				<xsl:with-param name="parentStyleName" select="@style:name"/>
				<xsl:with-param name="parentStyleFamily" select="@style:family"/>
				<xsl:with-param name="searchOnlyInAutomaticStyles"/>
			</xsl:call-template>

		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
